==> CGAL-6.0.1-doc_html.tar.xz: doc_html/Kernel_23/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "CGAL 6.0.1 - 2D and 3D Linear Geometry Kernel", "index.html", [
    [ "User Manual", "index.html", "index" ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"Filtered_kernel_2Filtered_predicate_8cpp-example.html",
"classCGAL_1_1Iso__rectangle__2.html#ae5fa468ae40345d66893dd56cf80ee75",
"classCGAL_1_1Sphere__3.html#a6203b9f4a4afeac40758499e1aec9f6b",
"classKernel.html#a33eef3ded1c90e357728ec13ddd0de5b",
"classKernel_1_1Angle__3.html#a8f9c12ba6e2210f50fb6a192df9e3af4",
"classKernel_1_1ComputeVolume__3.html#a74e33e215c888bf11f5fbe40241ac831",
"classKernel_1_1ConstructPointOn__3.html#aa18da4ad00632312e6eb56d5d9a40830",
"classKernel_1_1IsDegenerate__3.html#a5dc48e597385a16e47e6b49924332c5c",
"group__compare__xy__spherical__grp.html",
"index.html#Kernel_23CartesianKernels"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> CGAL-6.1-doc_html.tar.xz: doc_html/Kernel_23/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "CGAL 6.1 - 2D and 3D Linear Geometry Kernel", "index.html", [
    [ "User Manual", "index.html", "index" ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"Filtered_kernel_2Filtered_predicate_8cpp-example.html",
"classCGAL_1_1Iso__rectangle__2.html#ae5fa468ae40345d66893dd56cf80ee75",
"classCGAL_1_1Sphere__3.html#a6203b9f4a4afeac40758499e1aec9f6b",
"classKernel.html#a33eef3ded1c90e357728ec13ddd0de5b",
"classKernel_1_1Angle__3.html#a8f9c12ba6e2210f50fb6a192df9e3af4",
"classKernel_1_1ComputeVolume__3.html#a74e33e215c888bf11f5fbe40241ac831",
"classKernel_1_1ConstructPointOn__3.html#aa18da4ad00632312e6eb56d5d9a40830",
"classKernel_1_1IsDegenerate__3.html#a3df365dab543fc779c23aa031b3aa741",
"group__compare__xy__linear__grp.html",
"index.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
